Merge variants from multiple callers and return a data frame of merged calls. By default filtering is also applied, although this behaviour can be turned off by setting apply.filters to FALSE.
# S3 method for variants
merge(variant.specification, apply.filters = TRUE,
remove.structural.variants = TRUE,
separate.consensus.filters = FALSE, verbose = FALSE)Data frame containing details of file paths, sample IDs, and caller.
Logical indicating whether to apply filters. Defaults to TRUE.
Logical indicating whether structural variants (including CNVs) should be removed. Defaults to TRUE.
Logical indicating whether to apply different thresholds to variants called by more than one caller (specified under consensus in config file). Defaults to FALSE.
Logical indicating whether to print information to screen
Data frame