This function prepares a data frame that can be used to run variant callers. For matched normal variant calling, this data frame will contain three columns with names: sample.id, tumour.bam, normal.bam For unpaired variant calling, the data frame will contain two columns with names: sample.id, tumour.bam
prepare.bam.specification(sample.details, paired = TRUE,
sample.id.column = 1, tumour.bam.column = 2, normal.bam.column = 3)Data frame where each row represents a sample to be run. Must contain sample ID, path to tumour BAM, and path to normal BAM.
Logical indicating whether the sample specification is for a paired analysis.
Index or string giving column of sample.details that contains the sample ID
Index or string giving column of sample.details that contains the path to the tumour BAM
Index or string giving column of sample.details that contains the path to the normal BAM
bam.specification Data frame with one row per sample to be run