Prepare FASTQ specification data frame to standardized format for downstream analyses.
prepare.fastq.specification(sample.details, sample.id.column = 1,
fastq.columns = c(2, 3), patient.id.column = NA,
tissue.column = NA)Data frame where each row represents a sample to be run. Must contain sample ID, path to tumour BAM, and path to normal BAM.
Index or string giving column of sample.details that contains the sample ID
Index or string giving column(s) of sample.details that contain path to FASTQ files
Index or string giving column of sample.details that contains the patient ID
Index or string giving column of sample.details that contains information on tissue (tumour/ normal)
Data frame with one row per sample to be run
This function prepares a data frame that can be used to run alignment. For paired-end reads, this data frame will contain three columns with names: sample.id, reads, mates For single-end reads, the data frame will contain two columns with names: sample.id, reads