Read all calls made with a certain caller
read.all.calls(sample.ids, caller = c("vardict", "mutect", "pgm"),
project.directory, patient.ids = NULL, apply.filters = TRUE,
variant.file.pattern = NULL)Vector giving sample IDs to process
String indicating which caller was used
Path to project directory
Optional vector giving patient ID (or other group) corresponding to each sample
Logical indicating whether filters specified in VariTAS options should be applied. Defaults to TRUE. !
Pattern indicating where the variant file can be found. Sample ID should be indicated by SAMPLE_ID
combined.variant.calls Data frame with variant calls from all patients