read.variant.calls: Read variant calls from file and format for ease of downstream analyses.
Description
Read variant calls from file and format for ease of downstream analyses.
Usage
read.variant.calls(variant.file, variant.caller)
Arguments
variant.caller
String indicating which variant caller was used. Needed to format the headers.
Value
variant.calls Data frame of variant calls