Run ANNOVAR on a VCF file
run.annovar.vcf(vcf.file, output.directory = NULL,
output.filename = NULL, code.directory = NULL,
log.directory = NULL, config.file = NULL, job.dependencies = NULL,
job.group = NULL, job.name = NULL, isis = FALSE, quiet = FALSE,
verify.options = !quiet)Path to VCF file
Path to output directory
Name of resulting VCF file (defaults to SAMPLE_ID.vcf)
Path to directory where code should be stored
Path to directory where log files should be stored
Path to config file
Vector with names of job dependencies
Group job should belong to
Name of job to be submitted
Logical indicating whether VCF files are from the isis (MiniSeq) variant caller
Logical indicating whether to print command to screen rather than submit it to the system. Defaults to false, useful for debugging.
Logical indicating whether to run verify.varitas.options
None