Run filtering on an ANNOVAR-annotated txt file
run.filtering.txt(variant.file, caller = c("consensus", "vardict",
"ides", "mutect"), output.directory = NULL, output.filename = NULL,
code.directory = NULL, log.directory = NULL, config.file = NULL,
job.dependencies = NULL, job.group = NULL, quiet = FALSE)Path to variant file
String giving variant caller that was used (affects which filters were applied.
Path to output directory
Name of resulting VCF file (defaults to SAMPLE_ID.vcf)
Path to directory where code should be stored
Path to directory where log files should be stored
Path to config file
Vector with names of job dependencies
Group job should belong to
Logical indicating whether to print command to screen rather than submit it to the system. Defaults to false, useful for debugging.