Perform sample QC by looking at target coverage.
run.target.qc(bam.specification, project.directory,
sample.directories = TRUE, paired = FALSE,
output.subdirectory = FALSE, quiet = FALSE, job.name.prefix = NULL,
verify.options = FALSE, job.group = "target_qc")Data frame containing details of BAM files to be processed, typically from prepare.bam.specification.
Path to project directory where code and log files should be saved
Logical indicating whether output for each sample should be put in its own directory (within output.directory)
Logical indicating whether the analysis is paired. This does not affect QC directly, but means normal samples get nested
If further nesting is required, name of subdirectory. If no further nesting, set to FALSE
Logical indicating whether to print commands to screen rather than submit the job
Prefix for job names on the cluster
Logical indicating whether to run verify.varitas.options
Group job should be associated with on cluster