verify.bwa.index: verify.bwa.index
Description
Verify that bwa index files exist for a fasta file
Usage
verify.bwa.index(fasta.file, error = FALSE)
Arguments
error
Logical indicating whether to throw an (informative) error if verification fails
Value
index.files.exist Logical indicating if bwa index files were found (only returned if error set to FALSE)