verify.fasta.index: verify.fasta.index
Description
Verify that fasta index files exist for a given fasta file.
Usage
verify.fasta.index(fasta.file, error = FALSE)
Arguments
error
Logical indicating whether to throw an (informative) error if verification fails
Value
faidx.exists Logical indicating if fasta index files were found (only returned if error set to FALSE)