Check that FASTQ specification data frame matches expected format, and that all files exist
verify.fastq.specification(fastq.specification, paired.end = FALSE,
files.ready = FALSE)Data frame containing columns sample.id and reads, and optionally a column mates
Logical indicating whether paired end reads are used
Logical indicating if the files already exist on disk. If there are job dependencies, this should be set to FALSE.
None